===========
astroph_new
===========

``astropy_new`` is a python module to search for
`new astrophysics submissions <https://arxiv.org/list/astro-ph/new>`_
in `arXiv <https://arxiv.org>`_ based on the user interests and to create a
summarized document that can be easily opened in any browser.

- Docs: https://astroph-new.readthedocs.io

Installation: ``pip install -U astroph-new``

Features
========

- Managing user interests (subjects, author names, and keywords)
- Searching for new submissions in
  `astro-ph <https://arxiv.org/list/astro-ph/new>`_ based on the user interests
- Creating a summarized HTML document of the interested submissions
- Daily automatic searching and summary on a set time.

License
=======

All files are under MIT License, see `LISENCE <LICENSE>`_.
